Check if the database based on the given data source is ready
Usage
check_source(group = getOption("tarflow.group"))Arguments
- group
Section identifier in the
default.file. SeeRMariaDB::MariaDB()for more information.
Check if the database based on the given data source is ready
check_source(group = getOption("tarflow.group"))Section identifier in the default.file. See
RMariaDB::MariaDB() for more information.