This function is a memoised version of fetch_iquizoo(). It is useful when
the same query is called multiple times or you want to cache the result. See
memoise::memoise() and fetch_iquizoo() for more details.
Arguments
- cache
The cache to be used. Default cache could be configured by setting the environment variable
TARFLOW_CACHEto"disk"or"memory". If setTARFLOW_CACHEto"disk", the cache will be stored in disk at~/.cache/tarflow.iquizoowith a maximal age of 7 days. If setTARFLOW_CACHEto"memory", the cache will be stored in memory. You can also setcacheto a custom cache, seememoise::memoise()for more details.
Value
A memoised version of fetch_iquizoo().
See also
fetch_iquizoo() for the original function.