If you want to extract data based on your own parameters, you should use this function to set up your own SQL templates. Note that the SQL queries should be parameterized.
Usage
setup_templates(
contents = NULL,
users = NULL,
raw_data = NULL,
scores = NULL,
progress_hash = NULL
)Arguments
- contents
The SQL template file used to fetch contents. At least
project_idandgame_idcolumns should be included in the fetched data based on the template.project_idwill be used as the only parameter inusersandprojecttemplates, while all three will be used inraw_dataandscorestemplates.- users
The SQL template file used to fetch users. Usually you don't need to change this.
- raw_data
The SQL template file used to fetch raw data. See
fetch_data()for details. Usually you don't need to change this.- scores
The SQL template file used to fetch scores. See
fetch_data()for details. Usually you don't need to change this.- progress_hash
The SQL template file used to fetch progress hash. Usually you don't need to change this.