This target factory is the main part of the tar_prep_iquizoo function. It
fetches the raw data and scores for each project and task/game combination.
Usage
tar_fetch_data(
contents,
what = c("raw_data", "scores"),
templates = setup_templates(),
check_progress = TRUE
)Arguments
- contents
The contents structure used as the configuration of data fetching.
- what
What to fetch.
- templates
The SQL template files used to fetch data. See
setup_templates()for details.- check_progress
Whether to check the progress hash. If set as
TRUE, Before fetching the data, the progress hash objects named asprogress_hash_{project_id}will be depended on, which are typically generated bytar_prep_hash(). If the projects are finalized, set this argument asFALSE.